const { contextBridge, ipcRenderer } = require('electron');

// 在window加载完成时执行
window.addEventListener('DOMContentLoaded', () => {
  console.log('预加载脚本已执行');
  
  try {
    // 使用更安全的方式添加调试信息
    const debugDiv = document.createElement('div');
   /*  debugDiv.id = 'electron-debug';
    debugDiv.textContent = 'Electron已加载';
    debugDiv.style.position = 'fixed';
    debugDiv.style.bottom = '10px';
    debugDiv.style.right = '10px';
    debugDiv.style.padding = '5px';
    debugDiv.style.background = 'rgba(0,0,0,0.7)';
    debugDiv.style.color = 'white';
    debugDiv.style.zIndex = '9999'; */
    
    // 等待DOM完全加载
    setTimeout(() => {
      if (document.body) {
        document.body.appendChild(debugDiv);
      }
    }, 1000);
  } catch (e) {
    console.error('预加载脚本错误:', e);
  }
});

// 使用contextBridge安全地暴露API
contextBridge.exposeInMainWorld('electronAPI', {
  versions: process.versions,
  isElectron: true,
  loadApp: (route) => ipcRenderer.send('load-app', route),
  platform: process.platform,
  saveSettings: (settings) => ipcRenderer.send('save-settings', settings),
  getSettings: () => ipcRenderer.invoke('get-settings')
});